@@ -21,13 +21,22 @@
  */
 package org.wildfly.clustering.web.sso;
 
-import org.wildfly.clustering.web.IdentifierFactory;
-import org.wildfly.clustering.web.LocalContextFactory;
+import org.wildfly.clustering.ee.Batch;
 
 /**
  * Factory for creating SSO manager instances.
- * @author Paul Ferraro
+ * @param <A> authentication type
+ * @param <D> deployment type
+ * @param <S> session type
+ * @param <B> batch type
  */
-public interface SSOManagerFactory<I, D> {
-    <L> SSOManager<I, D, L> createSSOManager(IdentifierFactory<String> identifierFactory, LocalContextFactory<L> localContextFactory);
+public interface SSOManagerFactory<A, D, S, B extends Batch> {
+    /**
+     * Creates a new SSO manager using the specified configuration.
+     * @param <C> marshalling context type
+     * @param <L> local context type
+     * @param config a SSO manager configuration
+     * @return a new SSO manager
+     */
+    <C, L> SSOManager<A, D, S, L, B> createSSOManager(SSOManagerConfiguration<C, L> config);
 }
